@@ -104,18 +104,18 @@ if ($adminer->homepage()) {
 						echo ($link ? "<td align='right'>" . (support("table") || $key == "Rows" || (support("indexes") && $key != "Data_length")
 							? "<a href='" . h(ME . "$link[0]=") . urlencode($name) . "'$id title='$link[1]'>?</a>"
 							: "<span$id>?</span>"
-						) : "<td id='$key-" . h($name) . "'>&nbsp;");
+						) : "<td id='$key-" . h($name) . "'>");
 					}
 					$tables++;
 				}
-				echo (support("comment") ? "<td id='Comment-" . h($name) . "'>&nbsp;" : "");
+				echo (support("comment") ? "<td id='Comment-" . h($name) . "'>" : "");
 			}
 
-			echo "<tr><td>&nbsp;<th>" . lang('%d in total', count($tables_list));
-			echo "<td>" . nbsp($jush == "sql" ? $connection->result("SELECT @@storage_engine") : "");
-			echo "<td>" . nbsp(db_collation(DB, collations()));
+			echo "<tr><td><th>" . lang('%d in total', count($tables_list));
+			echo "<td>" . h($jush == "sql" ? $connection->result("SELECT @@storage_engine") : "");
+			echo "<td>" . h(db_collation(DB, collations()));
 			foreach (array("Data_length", "Index_length", "Data_free") as $key) {
-				echo "<td align='right' id='sum-$key'>&nbsp;";
+				echo "<td align='right' id='sum-$key'>";
 			}
 
 			echo "</table>\n";
@@ -159,7 +159,7 @@ if ($adminer->homepage()) {
 			$routines = routines();
 			if ($routines) {
 				echo "<table cellspacing='0'>\n";
-				echo '<thead><tr><th>' . lang('Name') . '<td>' . lang('Type') . '<td>' . lang('Return type') . "<td>&nbsp;</thead>\n";
+				echo '<thead><tr><th>' . lang('Name') . '<td>' . lang('Type') . '<td>' . lang('Return type') . "<td></thead>\n";
 				odd('');
 				foreach ($routines as $row) {
 					$name = ($row["SPECIFIC_NAME"] == $row["ROUTINE_NAME"] ? "" : "&name=" . urlencode($row["ROUTINE_NAME"])); // not computed on the pages to be able to print the header first
