@@ -183,7 +183,7 @@ $translations = array(
 	'Save and continue edit' => '儲存並繼續編輯',
 	'original' => '原始',
 	'%d item(s) have been affected.' => '%d個項目受到影響。',
-	'whole result' => '所有結果',
+	'Whole result' => '所有結果',
 	'Tables have been dropped.' => '已經將資料表刪除。',
 	'Clone' => '複製',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => '超過允許的字段數量的最大值。請增加%s。',
